<?php

/**
 * @file
 * Adhan settings UI
 */

/**
 * Provides the settings form.
 */
function adhan_admin() {
  $date_formats = array(
    'Y-m-d',
    'm/d/Y',
    'd/m/Y',
    'Y/m/d',
    'd.m.Y',
  );
  $time_formats = array(
    'H:i:s',
    'H:i',
    'h:ia',
  );

  foreach ($date_formats as $f) {
    $date_options[$f] = format_date(time(), 'custom', $f);
  }
  foreach ($time_formats as $f) {
    $time_options[$f] = format_date(time(), 'custom', $f);
  }

  $form['adhan_interface'] = array(
    '#type' => 'fieldset',
    '#title' => t("Interface options"),
  );
  $form['adhan_interface']['adhan_gif'] = array(
    '#type' => 'checkbox',
    '#title' => t("Optimize compass for bandwidth"),
    '#description' => t("Generates the compass in gif format instead of png"),
    '#default_value' => variable_get('adhan_gif', 0),
  );
  $form['adhan_interface']['adhan_notify'] = array(
    '#type' => 'radios',
    '#title' => t("Adhan notification"),
    '#description' => t('Choose the way visitors will be notified. Requires <a href="@url">jQuery_ui</a>.', array('@url' => 'http://drupal.org/project/jquery_ui')),
    '#default_value' => variable_get('adhan_notify', 0),
    '#options' => array(
      t("No notification"),
      t("Popup"),
      t("Popup and play adhan"),
    ),
  );

  $form['adhan_location'] = array(
    '#type' => 'fieldset',
    '#title' => t("Location"),
  );
  $form['adhan_location']['adhan_geolocate'] = array(
    '#type' => 'checkbox',
    '#title' => t("Use geolocation"),
    '#description' => t('Try to determine the location of visitors. Requires <a href="@url">Smart IP</a>.', array('@url' => 'http://drupal.org/project/smart_ip')),
    '#default_value' => variable_get('adhan_geolocate', 0),
  );
  $form['adhan_location']['adhan_loc'] = array(
    '#type' => 'textfield',
    '#title' => t("Location name"),
    '#description' => t("The name of the location, like a city or a town."),
    '#default_value' => variable_get('adhan_loc', t("The Hague")),
  );
  $form['adhan_location']['adhan_lat'] = array(
    '#type' => 'textfield',
    '#title' => t("Latitude"),
    '#default_value' => variable_get('adhan_lat', 52.07),
  );
  $form['adhan_location']['adhan_lng'] = array(
    '#type' => 'textfield',
    '#title' => t("Longitude"),
    '#default_value' => variable_get('adhan_lng', 4.29),
  );

  $form['adhan_date'] = array(
    '#type' => 'fieldset',
    '#title' => t("Date/time settings"),
  );
  $form['adhan_date']['adhan_date'] = array(
    '#type' => 'select',
    '#title' => t("Date format"),
    '#description' => t("Select the date format to use for Adhan"),
    '#default_value' => variable_get('adhan_date', 'd/m/Y'),
    '#options' => $date_options,
  );
  $form['adhan_date']['adhan_time'] = array(
    '#type' => 'select',
    '#title' => t("Time format"),
    '#description' => t("Select the time format to use for Adhan"),
    '#default_value' => variable_get('adhan_time', 'H:i:s'),
    '#options' => $time_options,
  );

  $form['adhan_calculation'] = array(
    '#type' => 'fieldset',
    '#title' => t("Calculation settings"),
  );
  $form['adhan_calculation']['adhan_method'] = array(
    '#type' => 'radios',
    '#title' => t("Calculation method"),
    '#description' => t("The default calculation method to use"),
    '#default_value' => variable_get('adhan_method', 0),
    '#options' => array(
      t("Karachi"),
      t("ISNA"),
      t("Muslim World League"),
      t("Makkah"),
      t("Egypt"),
    ),
  );
  $form['adhan_calculation']['adhan_asr_method'] = array(
    '#type' => 'radios',
    '#title' => t("Asr calculation method"),
    '#description' => t("The default calculation method for the Asr prayer"),
    '#default_value' => variable_get('adhan_asr_method', 0),
    '#options' => array(t("Shafii"), t("Hanafi")),
  );

  return system_settings_form($form);
}
